# uv GO tool

An easy way to launch programs with functional bonuses

[![PyPI](https://img.shields.io/pypi/v/uv-go)](https://pypi.org/project/uv-go/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/uv-go)](https://pypi.org/project/uv-go/)
[![uvxt](https://img.shields.io/badge/family-uvxt-purple)](https://pypi.org/project/uvxt/)

[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=rocshers_uv-go&metric=coverage)](https://sonarcloud.io/summary/new_code?id=rocshers_uv-go)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=rocshers_uv-go&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=rocshers_uv-go)

[![Downloads](https://static.pepy.tech/badge/uv-go)](https://pepy.tech/project/uv-go)
[![GitLab stars](https://img.shields.io/gitlab/stars/rocshers/python/uv-go)](https://gitlab.com/rocshers/python/uv-go)
[![GitLab last commit](https://img.shields.io/gitlab/last-commit/rocshers/python/uv-go)](https://gitlab.com/rocshers/python/uv-go)

## Quick start

```bash
uvx uv-go module.file:function_main.function_property

# Or using uvxt
uv tool install uvxt
uvxt go module.file:function_main.function_property
```

## Contribute

Issue Tracker: <https://gitlab.com/rocshers/python/uv-go/-/issues>  
Source Code: <https://gitlab.com/rocshers/python/uv-go>

Before adding changes:

```bash
make install
```

After changes:

```bash
make format test
```
